import com.google.gson.Gson;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonParser;
import com.sun.istack.internal.NotNull;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;

public class Main {

    private static final String FRIENDS_URL_FMT = "https://api.vk.com/method/friends.get?user_id=%s&fields=city&count=5&order=name";

    public static void main(String[] args) throws IOException {
        if (args.length == 0) {
            System.out.println("Введите id пользователя");
            return;
        }

        String id = args[0];
        // Получаем строку-json
        String json = getJsonFromUrl(String.format(FRIENDS_URL_FMT, id));
        // Парсим массив пользователей
        User[] friends = parseUsersFromJson(json);

        // Выводим результат
        if (friends.length == 0) {
            System.out.println("У пользователя \"" + id + "\" нет друзей");
        } else {
            System.out.println("Первые 5 друзей пользователя \"" + id + "\"");
            for (User friend : friends) {
                System.out.println(friend);
            }
        }
    }

    /**
     * Возвращает строку-json
     *
     * @param urlString url-адрес
     * @return строка-json
     */
    @NotNull
    private static String getJsonFromUrl(String urlString) throws IOException {
        URL url = new URL(urlString);
        HttpURLConnection connection = (HttpURLConnection) url.openConnection();
        connection.setConnectTimeout(10000);
        connection.setDoInput(true);
        connection.connect();

        try {
            if (connection.getResponseCode() != HttpURLConnection.HTTP_OK) {
                return "[]";
            }

            InputStream in = connection.getInputStream();

            JsonElement jsonElement = new JsonParser().parse(new InputStreamReader(in));
            JsonObject jsonObject = jsonElement.getAsJsonObject();

            return (jsonObject.has("response"))
                    ? jsonObject.get("response").toString()
                    : "[]";
        } finally {
            connection.disconnect();
        }
    }

    /**
     * Возвращает массив пользователей
     *
     * @param json строка-json
     * @return Массив пользователей
     */
    @NotNull
    private static User[] parseUsersFromJson(String json) {
        return new Gson().fromJson(json, User[].class);
    }
}
